@@ -1,4 +1,5 @@
-use crate::config::{clean_config_dir, make_config_dir, InnisfreeError, ServicePort};
+use crate::config::{clean_config_dir, make_config_dir, ServicePort};
+use crate::error::InnisfreeError;
 use crate::proxy::proxy_handler;
 use crate::server::InnisfreeServer;
 use crate::wg::WireguardManager;
@@ -243,6 +244,7 @@ impl InnisfreeManager {
         // Ignore errors, since we want to try all handlers
         let _ = self.bring_down_local_wg();
         let _ = self.server.destroy().await;
+        clean_config_dir(&self.name);
     }
     pub async fn assign_floating_ip(&self, floating_ip: &str) {
         self.server.assign_floating_ip(floating_ip).await;
